django-hashlink
===============

Store and retrieve URL hash (fragment) based webpage state in MongoDB
through Django_.

.. _Django: https://www.djangoproject.com/
.. _MongoDB: http://www.mongodb.org/

Documentation is found at:

http://django-hashlink.readthedocs.org/
